export namespace LarkEvent {
  /**
   * 消息事件头
   */
  export interface Header {
    /**
     * 事件ID
     * @example 0f8ab23b60993cf8dd15c8cde4d7b0f5
     */
    event_id: string
    /**
     * token
     * @example tV9djUKSjzVnekV7xTg2Od06NFTcsBnj
     */
    token: string
    /**
     * 创建时间戳
     * @example 1693565712117
     */
    create_time: string
    /**
     * 事件类型
     * @example im.message.receive_v1
     */
    event_type: string
    /**
     * tenant_key
     * @example 2ee61fe50f4f1657
     */
    tenant_key: string
    /**
     * app_id
     * @example cli_a1eff35b43b89063
     */
    app_id: string
  }
  /**
   * 被AT的人的信息
   */
  export interface Mention {
    /**
     * 被艾特的人的ID信息
     */
    id: UserIdInfo
    /**
     * 对应到文本内的内容
     * @example "@_user_1"
     */
    key: string
    /**
     * 用户名
     * @example 小煎蛋
     */
    name: string
    /**
     * 应用ID
     * @example 2ee61fe50f4f1657
     */
    tenant_key: string
  }
  /**
   * 消息内容信息
   */
  export interface Message {
    /**
     * 对话流ID
     * @example oc_433b1cb7a9dbb7ebe70a4e1a59cb8bb1
     */
    chat_id: string
    /**
     * 消息类型
     * @example group | p2p
     */
    chat_type: "group" | "p2p"
    /**
     * JSON字符串文本内容
     * @example "{\"text\":\"@_user_1 测试\"}"
     */
    content: string
    /**
     * 消息发送时间戳
     * @example 1693565711996
     */
    create_time: string
    /**
     * 被艾特的人信息
     */
    mentions?: Mention[]
    /**
     * 当前消息的ID
     * @example om_038fc0eceed6224a1abc1cdaa4266405
     */
    message_id: string
    /**
     * 消息类型
     * @example text、post、image、file、audio、media、sticker、interactive、share_chat、share_user
     */
    message_type:
      | "text"
      | "post"
      | "image"
      | "file"
      | "audio"
      | "media"
      | "sticker"
      | "interactive"
      | "share_chat"
      | "share_user"
  }

  /**
   * 用户ID信息
   */
  export interface UserIdInfo {
    /**
     * 用户标记
     * @example ou_032f507d08f9a7f28b042fcd086daef5
     */
    open_id: string
    /**
     * 用户标记
     * @example on_7111660fddd8302ce47bf1999147c011
     */
    union_id: string
    /**
     * 用户名
     * @example zhaoyingbo
     */
    user_id: string
  }
  /**
   * 消息发送者信息
   */
  export interface Sender {
    /**
     * id 相关信息
     */
    sender_id: UserIdInfo
    /**
     * 发送者类型
     * @example user
     */
    sender_type: string
    /**
     * 应用ID
     * @example 2ee61fe50f4f1657
     */
    tenant_key: string
  }
  /**
   * 事件详情
   */
  export interface Event {
    message: Message
    sender: Sender
  }

  export interface Data {
    /**
     * 协议版本
     * @example 2.0
     */
    schema: string
    /**
     * 事件头
     */
    header: Header
    /**
     * 事件详情
     */
    event: Event
  }
}
